@@ -54,24 +54,19 @@ def uiopen(title,filetypes):
 	root.destroy()
 	return file_in
 
-def download_soundfont(fonts):
+def download_soundfont(name):
 	'''
 	Downloads soundfonts from https://sites.google.com/site/soundfonts4u/
 	'''
-	if type(fonts) is not list:
-		fonts = [fonts]
 	sf_path = os.path.join(os.path.dirname(os.path.abspath(__file__)),'anthem_soundfonts')
-	if not os.path.isdir(sf_path):
-		os.mkdir(sf_path)
 	try:
-		for font in fonts:
-			if not os.path.isfile(os.path.join(sf_path,font+'.sf2')):
-				gdd.download_file_from_google_drive(file_id=sound_fonts[font],dest_path=os.path.join(sf_path,font+'.sf2'))
-				print(f'Sound font {font} downloaded to soundfont library.')
-			else:
-				print(f'Sound font {font} already present in soundfont library.')
+		if not os.path.isfile(os.path.join(sf_path,name+'.sf2')):
+			gdd.download_file_from_google_drive(file_id=sound_fonts[name],dest_path=os.path.join(sf_path,name+'.sf2'),showsize=True)
+			print(f'Sound font "{name}.sf2" downloaded to soundfont library.')
+		else:
+			print(f'Sound font "{name}.sf2" already present in soundfont library.')
 	except:
-		print(f'Sound font {font} is not available font. Please choose from these: {sound_fonts.keys()}')
+		print(f'Sound font "{name}.sf2" is not an available font. Please choose from these: {sound_fonts.keys()}')
 
 def run(display=True):
 	'''
@@ -93,7 +88,12 @@ class GUI(Tk):
 		'''
 		self.display=display
 		self.tooltips_on=False
-		download_soundfont(sound_fonts)
+		self.sf_path = os.path.join(os.path.dirname(os.path.abspath(__file__)),'anthem_soundfonts')
+		if not os.path.isdir(self.sf_path):
+			print('Initializing soundfont library...')
+			os.mkdir(self.sf_path)
+		for f in sound_fonts.keys():
+			download_soundfont(f)
 		if self.display:
 			Tk.__init__(self)
 			self.default_font=font.nametofont("TkDefaultFont")
